Modules
- tree_
state - Public so
cargo test --libcan exercise the same filebuild.rscompiles via#[path]. ~keep Classifies the working tree a binary was built from asclean,dirty, orunknown.
cargo test --lib can exercise the same file build.rs compiles via #[path]. ~keep
Classifies the working tree a binary was built from as clean, dirty, or unknown.