pub struct AdapterParam {
pub name: String,
pub ty: String,
pub optional: bool,
}Expand description
A parameter in an adapter function.
Fields
name: Stringty: Stringoptional: boolTrait Implementations
Sourceimpl Clone for AdapterParam
impl Clone for AdapterParam
Sourcefn clone(&self) -> AdapterParam
fn clone(&self) -> AdapterParam
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AdapterParam
impl Debug for AdapterParam
Sourceimpl<'de> Deserialize<'de> for AdapterParam
impl<'de> Deserialize<'de> for AdapterParam
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AdapterParam
impl JsonSchema for AdapterParam
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AdapterParam
impl RefUnwindSafe for AdapterParam
impl Send for AdapterParam
impl Sync for AdapterParam
impl Unpin for AdapterParam
impl UnsafeUnpin for AdapterParam
impl UnwindSafe for AdapterParam