pub struct ResolvedE2eCallRecipe<'a> {
pub args: &'a [ArgMapping],
pub override_config: Option<&'a CallOverride>,
pub options_type: Option<&'a str>,
pub options_via: &'a str,
pub extra_args: &'a [String],
/* private fields */
}Fields
args: &'a [ArgMapping]override_config: Option<&'a CallOverride>options_type: Option<&'a str>options_via: &'a strextra_args: &'a [String]Implementations
Sourceimpl<'a> ResolvedE2eCallRecipe<'a>
impl<'a> ResolvedE2eCallRecipe<'a>
pub fn resolve( language: &str, fixture: &'a Fixture, call_config: &'a CallConfig, type_defs: &'a [TypeDef], ) -> Self
pub fn compatible_options_type( &self, compatible_languages: &[&str], ) -> Option<&'a str>
pub fn json_object_arg_has_default(&self, arg: &ArgMapping) -> bool
Sourcepub fn handle_config_type(&self, arg: &'a ArgMapping) -> Option<&'a str>
pub fn handle_config_type(&self, arg: &'a ArgMapping) -> Option<&'a str>
Resolve the config type used to materialize a handle argument.
Handle fixtures create an opaque owner before invoking the target call. The config type must come from explicit fixture/call metadata instead of language generators guessing a project-specific DTO name.